List of users
=============
Here is a list of organisations, projects and individuals that have notified me that they are using DHCPKit and want to
be listed here:

- `Solcon <http://www.solcon.nl/>`_ (sponsor!)

If you are using DHCPKit please let me know by sending an email to dhcpkit@steffann.nl. Please let me know if you want
to be mentioned on this page because I will not add any names here without explicit consent.

Participation
=============
DHCPKit is released under the GPLv3 license so you are free to use and adapt DHCPKit. If you distribute modified or
extended versions of DHCPKit you must honor the license and make your changes available under a compatible license.
If you would like to see extra features and/or options implemented and don't feel like writing the code yourself please
contact me on dhcpkit@steffann.nl.
